@@ -16,9 +16,8 @@ from . import helpers
 
 def data():
     path = CONFIG['paths']['registry']
-    # downloads from https://andylolz.github.io/iati-data-dump/
-    data_url = 'https://www.dropbox.com/s/kkm80yjihyalwes/' + \
-               'iati_dump.zip?dl=1'
+    # downloads from https://iati-data-dump.codeforiati.org
+    data_url = 'https://iati-data.s3.eu-west-1.amazonaws.com/iati_data.zip'
     shutil.rmtree(path, ignore_errors=True)
     makedirs(path)
     zip_filepath = join(path, 'iati_dump.zip')
@@ -90,12 +89,6 @@ _NEW_CODELIST_TMPL = 'https://iatistandard.org/' + \
 def _get_codelist_mappings(versions):
     all_codelists = CodelistSet()
 
-    def filter_complete(mapping):
-        try:
-            return all_codelists.get(mapping['codelist']).complete
-        except:
-            raise Exception(mapping['codelist'])
-
     path = join(CONFIG['paths']['standard'], 'codelist_mappings')
     shutil.rmtree(path, ignore_errors=True)
     makedirs(path)
@@ -114,8 +107,6 @@ def _get_codelist_mappings(versions):
             mapping_url = tmpl.format(version=version_path)
             mappings = requests.get(mapping_url).json()
 
-            mappings = list(filter(filter_complete, mappings))
-
             activity_mappings = [
                 x for x in mappings
                 if not x['path'].startswith('//iati-org')]
